@@ -302,7 +302,7 @@ plot.nls <-
     if (is.null(data)) {		# try to construct data
       alist <- lapply(as.list(allV), as.name)
       names(alist) <- allV
-      alist <- c(as.list(as.name("data.frame")), alist)
+      alist <- c(list(as.name("data.frame")), alist)
       mode(alist) <- "call"
       data <- eval(alist, sys.parent(1))
     } else {
@@ -559,7 +559,7 @@ plot.augPred <-
       args[["key"]] <-
 	list(lines = c(Rows(trellis.par.get("superpose.line"), 1:lLev),
 		       list(size = rep(3, lLev))),
-	     text = list(levels = levs), columns = lLev)
+	     text = list(levels = levs), columns = min(6, lLev))
     }
   } else {
     args[["key"]] <- key
